==> clutternomore-1.1.3%2B1.21.1-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/screen/AccessibilityScreenMixin.java <==
package dev.tazer.clutternomore.common.mixin.screen;

import dev.tazer.clutternomore.client.ShapeSwitcherOptionsScreen;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.Arrays;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_4185;
import net.minecraft.class_4189;

@Mixin(class_4189.class)
public abstract class AccessibilityScreenMixin {
    //? if >1.20.1 {
    @Inject(
            method = "addOptions",
            at = @At(value = "RETURN")
    )
    public void addOptions(CallbackInfo ci) {
        class_4185 shapeSwitcherButton = class_4185
                .method_46430(
                        class_2561.method_43471("key.clutternomore.shape_switcher"),
                        button -> ((ScreenAccessor) this).getMinecraft().method_1507(new ShapeSwitcherOptionsScreen(((class_4189) (Object) this), ((OptionsSubScreenAccessor) (this)).getOptions()))
                ).method_46434(0, 0, 150, 20).method_46431();
        ((OptionsSubScreenAccessor) this).getList().method_58227(List.of(shapeSwitcherButton));
    }
    //?} else {
    /*@Redirect(
            method = "createFooter",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/components/Button$Builder;bounds(IIII)Lnet/minecraft/client/gui/components/Button$Builder;")
    )
    private Button.Builder redirectCreateFooter(Button.Builder builder, int x, int y, int width, int height) {
        return builder.bounds(x - 80, y, width, height);
    }

    @Inject(
            method = "createFooter",
            at = @At(value = "RETURN")
    )
    private void injectCreateFooter(CallbackInfo ci) {
        Button shapeSwitcherButton = Button
                .builder(
                        Component.translatable("key.clutternomore.shape_switcher"),
                        button -> ((ScreenAccessor) this).getMinecraft().setScreen(new ShapeSwitcherOptionsScreen(((AccessibilityOptionsScreen) (Object) this), ((OptionsSubScreenAccessor) (this)).getOptions()))
                ).bounds(((ScreenAccessor) this).getWidth() / 2 + 80, ((ScreenAccessor) this).getHeight() - 27, 150, 20).build();
        ((ScreenAccessor) this).invokeAddRenderableWidget(shapeSwitcherButton);
    }
    *///?}
}

==> clutternomore-1.1.4%2B1.21.10-fabric-sources.jar: dev/tazer/clutternomore/common/mixin/screen/AccessibilityScreenMixin.java <==
package dev.tazer.clutternomore.common.mixin.screen;

import dev.tazer.clutternomore.client.ShapeSwitcherOptionsScreen;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.Redirect;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

import java.util.Arrays;
import java.util.List;
import net.minecraft.class_2561;
import net.minecraft.class_4185;
import net.minecraft.class_4189;

@Mixin(class_4189.class)
public abstract class AccessibilityScreenMixin {
    //? if >1.20.1 {
    @Inject(
            method = "addOptions",
            at = @At(value = "RETURN")
    )
    public void addOptions(CallbackInfo ci) {
        class_4185 shapeSwitcherButton = class_4185
                .method_46430(
                        class_2561.method_43471("key.clutternomore.shape_switcher"),
                        button -> ((ScreenAccessor) this).getMinecraft().method_1507(new ShapeSwitcherOptionsScreen(((class_4189) (Object) this), ((OptionsSubScreenAccessor) (this)).getOptions()))
                ).method_46434(0, 0, 150, 20).method_46431();
        ((OptionsSubScreenAccessor) this).getList().method_58227(List.of(shapeSwitcherButton));
    }
    //?} else {
    /*@Redirect(
            method = "createFooter",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/components/Button$Builder;bounds(IIII)Lnet/minecraft/client/gui/components/Button$Builder;")
    )
    private Button.Builder redirectCreateFooter(Button.Builder builder, int x, int y, int width, int height) {
        return builder.bounds(x - 80, y, width, height);
    }

    @Inject(
            method = "createFooter",
            at = @At(value = "RETURN")
    )
    private void injectCreateFooter(CallbackInfo ci) {
        Button shapeSwitcherButton = Button
                .builder(
                        Component.translatable("key.clutternomore.shape_switcher"),
                        button -> ((ScreenAccessor) this).getMinecraft().setScreen(new ShapeSwitcherOptionsScreen(((AccessibilityOptionsScreen) (Object) this), ((OptionsSubScreenAccessor) (this)).getOptions()))
                ).bounds(((ScreenAccessor) this).getWidth() / 2 + 80, ((ScreenAccessor) this).getHeight() - 27, 150, 20).build();
        //? if >1.21 {
        ((ScreenAccessor) this).invokeAddRenderableWidget(shapeSwitcherButton);
        //?} else {
        /^((AccessibilityOptionsScreen) (Object) this).addRenderableWidget(shapeSwitcherButton);
        ^///?}

    }
    *///?}
}
